@@ -8,7 +8,7 @@ use Dancer::Plugin;
 use Hash::MultiValue;
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our %VALIDATOR = (
     NOT_NULL => sub {
@@ -197,7 +197,7 @@ sub valid {
 
 =head1 NAME
 
-Dancer::Plugin::KossyValidator - 根据Kossy 中的 Validator 移植过来的模块
+Dancer::Plugin::KossyValidator - 根据 Kossy 中的 Validator 移植过来的模块
 
 =head1 SYNOPSIS
 
@@ -225,8 +225,8 @@ Dancer::Plugin::KossyValidator - 根据Kossy 中的 Validator 移植过来的模
         $result->has_error:Flag
         $result->messages:ArrayRef[`Str]
          
-        my $val = $result->valid('q');  # 注意取参数从 param 替换为 valid 了
-        my @val = $result->valid('area');
+        my $val = $result->valid('name');  # 注意取请求过来的参数时原函数 param 替换为 valid 了
+        my @val = $result->valid('description');
          
         my $hash = $result->valid:Hash::MultiValue;
         # ...
